@@ -107,9 +107,6 @@ FAILEDOPERATION_PUBLISHLAYERVERSION = 'FailedOperation.PublishLayerVersion'
 # You cannot publish a version in the current function state. Please try again when the state is normal.
 FAILEDOPERATION_PUBLISHVERSION = 'FailedOperation.PublishVersion'
 
-# The role does not exist.
-FAILEDOPERATION_QCSROLENOTFOUND = 'FailedOperation.QcsRoleNotFound'
-
 # The function already has a reserved concurrency setting task in progress. Please try again later.
 FAILEDOPERATION_RESERVEDINPROGRESS = 'FailedOperation.ReservedInProgress'
 
@@ -176,6 +173,9 @@ INVALIDPARAMETERVALUE_ACTION = 'InvalidParameterValue.Action'
 # Incorrect `AdditionalVersionWeights` parameter.
 INVALIDPARAMETERVALUE_ADDITIONALVERSIONWEIGHTS = 'InvalidParameterValue.AdditionalVersionWeights'
 
+# The default alias cannot be deleted. Please check and try again.
+INVALIDPARAMETERVALUE_ALIAS = 'InvalidParameterValue.Alias'
+
 # ApiGateway parameter error.
 INVALIDPARAMETERVALUE_APIGATEWAY = 'InvalidParameterValue.ApiGateway'
 
@@ -191,16 +191,13 @@ INVALIDPARAMETERVALUE_CFSPARAMETERDUPLICATE = 'InvalidParameterValue.CfsParamete
 # The value of `cfs` configuration item does not meet the specification.
 INVALIDPARAMETERVALUE_CFSPARAMETERERROR = 'InvalidParameterValue.CfsParameterError'
 
-# The CFS parameter format does not conform to the specification.
-INVALIDPARAMETERVALUE_CFSSTRUCTIONERROR = 'InvalidParameterValue.CfsStructionError'
-
 # Ckafka error.
 INVALIDPARAMETERVALUE_CKAFKA = 'InvalidParameterValue.Ckafka'
 
 # Cls error.
 INVALIDPARAMETERVALUE_CLS = 'InvalidParameterValue.Cls'
 
-# 
+# To modify CLS configuration, Role parameter is required. Please check and try again.
 INVALIDPARAMETERVALUE_CLSROLE = 'InvalidParameterValue.ClsRole'
 
 # Cmq error.
@@ -353,6 +350,9 @@ INVALIDPARAMETERVALUE_RUNTIME = 'InvalidParameterValue.Runtime'
 # The searchkey is not `Keyword`, `Tag`, or `Runtime`.
 INVALIDPARAMETERVALUE_SEARCHKEY = 'InvalidParameterValue.SearchKey'
 
+# SecretInfo error
+INVALIDPARAMETERVALUE_SECRETINFO = 'InvalidParameterValue.SecretInfo'
+
 # Invalid ServiceName.
 INVALIDPARAMETERVALUE_SERVICENAME = 'InvalidParameterValue.ServiceName'
 
@@ -479,9 +479,6 @@ RESOURCEINUSE_CMQ = 'ResourceInUse.Cmq'
 # Cos is in use.
 RESOURCEINUSE_COS = 'ResourceInUse.Cos'
 
-# This function already exists.
-RESOURCEINUSE_FUNCTION = 'ResourceInUse.Function'
-
 # This FunctionName already exists.
 RESOURCEINUSE_FUNCTIONNAME = 'ResourceInUse.FunctionName'
 
@@ -512,6 +509,9 @@ RESOURCENOTFOUND_ASYNCEVENT = 'ResourceNotFound.AsyncEvent'
 # Cdn does not exist.
 RESOURCENOTFOUND_CDN = 'ResourceNotFound.Cdn'
 
+# Unable to find the specified mount point under the specified CFS
+RESOURCENOTFOUND_CFSMOUNTINSNOTMATCH = 'ResourceNotFound.CfsMountInsNotMatch'
+
 # VPCs of the CFS instance and the SCF function are different.
 RESOURCENOTFOUND_CFSVPCNOTMATCH = 'ResourceNotFound.CfsVpcNotMatch'
 
